@@ -7,15 +7,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: ethna_handle.php,v 1.7 2006/11/28 04:52:53 ichii386 Exp $
+ *  @version    $Id: ethna_handle.php 456 2007-02-07 10:59:17Z ichii386 $
  */
 while (ob_get_level()) {
     ob_end_clean();
 }
 
-require_once 'PEAR.php';
-require_once 'Console/Getopt.php';
-
 // setup path seprator
 if (!defined('PATH_SEPARATOR')) {
     if (OS_WINDOWS) {
@@ -27,19 +24,24 @@ if (!defined('PATH_SEPARATOR')) {
     }
 }
 $base = dirname(dirname(dirname(__FILE__)));
-ini_set('include_path', ini_get('include_path') . PATH_SEPARATOR . "$base");
+ini_set('include_path', $base.PATH_SEPARATOR.ini_get('include_path'));
 
+require_once 'PEAR.php';
+require_once 'Console/Getopt.php';
 require_once 'Ethna/Ethna.php';
 
 // fetch arguments
-$getopt =& new Console_Getopt();
-$arg_list = $getopt->readPHPArgv();
+$arg_list = Console_Getopt::readPHPArgv();
+if (Ethna::isError($arg_list)) {
+    echo $arg_list->getMessage()."\n";
+    exit(2);
+}
 array_shift($arg_list);
 
 $eh =& new Ethna_Handle();
 
 list($my_arg_list, $arg_list) = _Ethna_HandleGateway_SeparateArgList($arg_list);
-$r = $getopt->getopt($my_arg_list, "v", array("version"));
+$r = Console_Getopt::getopt($my_arg_list, "v", array("version"));
 if (Ethna::isError($r)) {
     usage($eh);
     exit(1);
