@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_AppObject.php,v 1.25 2006/11/20 07:15:11 ichii386 Exp $
+ *  @version    $Id: Ethna_AppObject.php 451 2007-01-17 07:46:35Z ichii386 $
  */
 
 // {{{ Ethna_AppObject
@@ -91,7 +91,7 @@ class Ethna_AppObject
         $ctl =& $backend->getController();
 
         // DB֥Ȥ
-        $db_list =& $this->_getDBList();
+        $db_list = $this->_getDBList();
         if (Ethna::isError($db_list)) {
             return $db_list;
         } else if (is_null($db_list['rw'])) {
@@ -597,7 +597,7 @@ class Ethna_AppObject
      */
     function searchId($filter = null, $order = null, $offset = null, $count = null)
     {
-        if (is_null($filter) == false) {
+        if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
             if (Ethna::isError($r)) {
@@ -650,7 +650,7 @@ class Ethna_AppObject
     function searchProp($keys = null, $filter = null, $order = null,
                         $offset = null, $count = null)
     {
-        if (is_null($filter) == false) {
+        if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
             if (Ethna::isError($r)) {
@@ -1197,9 +1197,6 @@ class Ethna_AppObject
         $column = "";
         $keys = $keys === null ? array_keys($def) : to_array($keys);
         foreach ($keys as $key) {
-            if (isset($def[$key]) == false) {
-                continue;
-            }
             if ($column != "") {
                 $column .= ", ";
             }
@@ -1546,7 +1543,9 @@ class Ethna_AppObject
             $primary  = in_array('primary_key', $field_def['flags']);
             $seq      = in_array('sequence',    $field_def['flags']);
             $required = in_array('not_null',    $field_def['flags']);
-            $key      = in_array('key',         $field_def['flags']);
+            $key      = in_array('primary_key', $field_def['flags'])
+                        || in_array('multiple_key', $field_def['flags'])
+                        || in_array('unique_key', $field_def['flags']);
 
             switch ($field_def['type']) {
             case 'int':
