@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Controller.php,v 1.72 2006/11/28 04:52:53 ichii386 Exp $
+ *  @version    $Id: Ethna_Controller.php 459 2007-02-18 20:30:55Z ichii386 $
  */
 
 // {{{ Ethna_Controller
@@ -292,17 +292,21 @@ class Ethna_Controller
      *  @access public
      *  @param  string  $id     ץꥱID
      *  @return mixed   true:OK Ethna_Error:NG
+     *  @static
      */
-    function checkAppId($id)
+    function &checkAppId($id)
     {
-        if (strcasecmp($id, 'ethna') == 0 || strcasecmp($id, 'app') == 0) {
-            return Ethna::raiseError(sprintf("Application Id [%s] is reserved\n", $id));
+        $true = true;
+        if (strcasecmp($id, 'ethna') === 0
+            || strcasecmp($id, 'app') === 0) {
+            return Ethna::raiseError("Application Id [$id] is reserved\n");
         }
-        if (preg_match('/^[0-9a-zA-Z]+$/', $id) == 0) {
-            return Ethna::raiseError(sprintf("Only Numeric(0-9) and Alphabetical(A-Z) is allowed for Application Id\n"));
+        if (preg_match('/^[0-9a-zA-Z]+$/', $id) === 0) {
+            return Ethna::raiseError(
+                "Only Numeric(0-9) and Alphabetical(A-Z) is allowed for Application Id\n"
+            );
         }
-
-        return true;
+        return $true;
     }
 
     /**
@@ -311,13 +315,16 @@ class Ethna_Controller
      *  @access public
      *  @param  string  $action_name    ̾
      *  @return mixed   true:OK Ethna_Error:NG
+     *  @static
      */
-    function checkActionName($action_name)
+    function &checkActionName($action_name)
     {
-        if (preg_match('/^[a-zA-Z\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/', $action_name) == 0) {
-            return Ethna::raiseError(sprintf("invalid action name [$action_name]"));
+        $true = true;
+        if (preg_match('/^[a-zA-Z\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/',
+                       $action_name) === 0) {
+            return Ethna::raiseError("invalid action name [$action_name]");
         }
-        return true;
+        return $true;
     }
 
     /**
@@ -326,13 +333,16 @@ class Ethna_Controller
      *  @access public
      *  @param  string  $view_name    ӥ塼̾
      *  @return mixed   true:OK Ethna_Error:NG
+     *  @static
      */
-    function checkViewName($view_name)
+    function &checkViewName($view_name)
     {
-        if (preg_match('/^[a-zA-Z\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/', $view_name) == 0) {
-            return Ethna::raiseError(sprintf("invalid view name [$view_name]"));
+        $true = true;
+        if (preg_match('/^[a-zA-Z\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/',
+                       $view_name) === 0) {
+            return Ethna::raiseError("invalid view name [$view_name]");
         }
-        return true;
+        return $true;
     }
 
     /**
@@ -739,8 +749,6 @@ class Ethna_Controller
     {
         if (extension_loaded('xmlrpc') == false) {
             die("xmlrpc extension is required to enable this gateway");
-        } else if (ini_get('always_populate_raw_post_data') == false) {
-            die("always_populate_raw_post_data ini variable should be true to enable this gateway");
         }
 
         $c =& new $class_name(GATEWAY_XMLRPC);
@@ -912,16 +920,45 @@ class Ethna_Controller
      */
     function _trigger_XMLRPC($action_name = "")
     {
+        // prepare xmlrpc server
         $xmlrpc_gateway_method_name = "_Ethna_XmlrpcGateway";
-
         $xmlrpc_server = xmlrpc_server_create();
+
         $method = null;
-        $param = xmlrpc_decode_request($GLOBALS['HTTP_RAW_POST_DATA'], $method);
+        $param = xmlrpc_decode_request(file_get_contents('php://input'), $method);
         $this->xmlrpc_method_name = $method;
 
-        $request = xmlrpc_encode_request($xmlrpc_gateway_method_name, $param, array("output_type" => "xml", "verbosity" => "pretty", "escaping" => array('markup'), "version" => "xmlrpc", "encoding" => "utf-8")); 
-        xmlrpc_server_register_method($xmlrpc_server, $xmlrpc_gateway_method_name, $xmlrpc_gateway_method_name);
-        $r = xmlrpc_server_call_method($xmlrpc_server, $request, null, array("output_type" => "xml", "verbosity" => "pretty", "escaping" => array('markup'), "version" => "xmlrpc", "encoding" => "utf-8"));
+        $request = xmlrpc_encode_request(
+            $xmlrpc_gateway_method_name,
+            $param,
+            array(
+                'output_type'   => 'xml',
+                'verbosity'     => 'pretty',
+                'escaping'      => array('markup'),
+                'version'       => 'xmlrpc',
+                'encoding'      => 'utf-8'
+            )
+        ); 
+
+        xmlrpc_server_register_method(
+            $xmlrpc_server,
+            $xmlrpc_gateway_method_name,
+            $xmlrpc_gateway_method_name
+        );
+
+        // send request
+        $r = xmlrpc_server_call_method(
+            $xmlrpc_server,
+            $request,
+            null,
+            array(
+                'output_type'   => 'xml',
+                'verbosity'     => 'pretty',
+                'escaping'      => array('markup'),
+                'version'       => 'xmlrpc',
+                'encoding'      => 'utf-8'
+            )
+        );
 
         header('Content-Length: ' . strlen($r));
         header('Content-Type: text/xml; charset=UTF-8');
@@ -942,6 +979,8 @@ class Ethna_Controller
         }
 
         // ֥
+        $backend =& $this->getBackend();
+
         $form_name = $this->getActionFormName($method);
         $this->action_form =& new $form_name($this);
         $def = $this->action_form->getDef();
@@ -956,7 +995,8 @@ class Ethna_Controller
         }
 
         // Хåɽ¹
-        $backend =& $this->getBackend();
+        $backend->setActionForm($this->action_form);
+
         $session =& $this->getSession();
         $session->restore();
         $r = $backend->perform($method);
