@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_MailSender.php,v 1.8 2006/07/22 08:04:45 fujimoto Exp $
+ *  @version    $Id: Ethna_MailSender.php 462 2007-04-19 14:59:38Z ichii386 $
  */
 
 /** ᡼ƥץ졼ȥ: ľ */
@@ -74,17 +74,31 @@ class Ethna_MailSender
     /**
      *  ᡼
      *
+     *  $attach λˡ:
+     *  - ¸ΥեźդȤ
+     *  <code>
+     *  array('filename' => '/tmp/hoge.xls', 'content-type' => 'application/vnd.ms-excel')
+     *  </code>
+     *  - ʸ̾դźդȤ
+     *  <code>
+     *  array('name' => 'foo.txt', 'content' => 'this is foo.')
+     *  </code>
+     *  'content-type' ά 'application/octet-stream' Ȥʤ롣
+     *  ʣźդȤϾź0ϤޤդĤ롣
+     *
      *  @access public
-     *  @param  string  $to     ᡼襢ɥ쥹
-     *  @param  string  $type   ᡼ƥץ졼ȥ
-     *  @param  array   $macro  ƥץ졼ȥޥ($typeMAILSENDER_TYPE_DIRECTξϥ᡼)
-     *  @param  array   $attach źեե(array('content-type' => ..., 'content' => ...))
-     *  @return string  $tonullξƥץ졼ȥޥŬѸΥ᡼
+     *  @param  string  $to         ᡼襢ɥ쥹 (nullΤȤƤ return )
+     *  @param  string  $template   ᡼ƥץ졼̾ or 
+     *  @param  array   $macro      ƥץ졼ȥޥ or $templateMAILSENDER_TYPE_DIRECTΤȤϥ᡼)
+     *  @param  array   $attach     źեե
+     *  @return bool|string  mail() ؿ or ᡼
      */
-    function send($to, $type, $macro, $attach = null)
+    function send($to, $template, $macro, $attach = null)
     {
-        // ƥĺ
-        if ($type !== MAILSENDER_TYPE_DIRECT) {
+        // ᡼Ƥ
+        if ($template === MAILSENDER_TYPE_DIRECT) {
+            $mail = $macro;
+        } else {
             $renderer =& $this->getTemplateEngine();
 
             // ܾ
@@ -101,75 +115,103 @@ class Ethna_MailSender
                     $renderer->setProp($key, $value);
                 }
             }
-
-            $template = $this->def[$type];
-            ob_start();
-            $renderer->display(sprintf('%s/%s', $this->mail_dir, $template));
-            $mail = ob_get_contents();
-            ob_end_clean();
-        } else {
-            $mail = $macro;
+            if (isset($this->def[$template])) {
+                $template = $this->def[$template];
+            }
+            $mail = $renderer->perform(sprintf('%s/%s', $this->mail_dir, $template), true);
         }
-
-        if (is_null($to)) {
+        if ($to === null) {
             return $mail;
         }
 
-        // 
-        foreach (to_array($to) as $rcpt) {
-            list($header, $body) = $this->_parse($mail);
+        // ᡼ƤإåʸʬΥ
+        $mail = str_replace("\r\n", "\n", $mail);
+        list($header, $body) = $this->_parse($mail);
 
-            // multipartб
-            if ($attach != null) {
-                $boundary = Ethna_Util::getRandom(); 
-
-                $body = "This is a multi-part message in MIME format.\n\n" .
-                    "--$boundary\n" .
-                    "Content-Type: text/plain; charset=ISO-2022-JP\n\n" .
-                    "$body\n" .
-                    "--$boundary\n" .
-                    "Content-Type: " . $attach['content-type'] . "; name=\"" . $attach['name'] . "\"\n" .
-                    "Content-Transfer-Encoding: base64\n" . 
-                    "Content-Disposition: attachment; filename=\"" . $attach['name'] . "\"\n\n";
-                $body .= chunk_split(base64_encode($attach['content']));
-                $body .= "--$boundary--";
-            }
-
-            $body = str_replace("\r\n", "\n", $body);
-
-            // ɬפʥإåɲ
-            if (array_key_exists('mime-version', $header) == false) {
-                $header['mime-version'] = array('Mime-Version', '1.0');
-            }
-            if (array_key_exists('subject', $header) == false) {
-                $header['subject'] = array('Subject', 'no subject in original');
-            }
-            if (array_key_exists('content-type', $header) == false) {
-                if ($attach == null) {
-                    $header['content-type'] = array('Content-Type', 'text/plain; charset=ISO-2022-JP');
-                } else {
-                    $header['content-type'] = array('Content-Type', "multipart/mixed; boundary=\"$boundary\"");
+        // źեե (multipart)
+        if ($attach !== null) {
+            $attach = isset($attach[0]) ? $attach : array($attach);
+            $boundary = Ethna_Util::getRandom(); 
+            $body = "This is a multi-part message in MIME format.\n\n" .
+                "--$boundary\n" .
+                "Content-Type: text/plain; charset=iso-2022-jp\n" .
+                "Content-Transfer-Encoding: 7bit\n\n" .
+                "$body\n";
+            foreach ($attach as $part) {
+                if (isset($part['content']) === false
+                    && isset($part['filename']) && is_readable($part['filename'])) {
+                    $part['content'] = file_get_contents($part['filename']);
+                    $part['filename'] = basename($part['filename']);
                 }
-            }
-
-            $header_line = "";
-            foreach ($header as $key => $value) {
-                if ($key == 'subject') {
-                    // should be added by mail()
+                if (isset($part['content']) === false) {
                     continue;
                 }
-                if ($header_line != "") {
-                    $header_line = "$header_line\n";
+                if (isset($part['content-type']) === false) {
+                    $part['content-type'] = 'application/octet-stream';
                 }
-                $header_line .= $value[0] . ": " . $value[1];
-            }
+                if (isset($part['name']) === false) {
+                    $part['name'] = $part['filename'];
+                }
+                if (isset($part['filename']) === false) {
+                    $part['filename'] = $part['name'];
+                }
+                $part['name'] = preg_replace('/([^\x00-\x7f]+)/e',
+                    "Ethna_Util::encode_MIME('$1')", $part['name']); // XXX: rfc2231
+                $part['filename'] = preg_replace('/([^\x00-\x7f]+)/e',
+                    "Ethna_Util::encode_MIME('$1')", $part['filename']);
 
+                $body .=
+                    "--$boundary\n" .
+                    "Content-Type: " . $part['content-type'] . ";\n" .
+                        "\tname=\"" . $part['name'] . "\"\n" .
+                    "Content-Transfer-Encoding: base64\n" . 
+                    "Content-Disposition: attachment;\n" .
+                        "\tfilename=\"" . $part['filename'] . "\"\n\n";
+                $body .= chunk_split(base64_encode($part['content']));
+            }
+            $body .= "--$boundary--";
+        }
+
+        // إå
+        if (isset($header['mime-version']) === false) {
+            $header['mime-version'] = array('Mime-Version', '1.0');
+        }
+        if (isset($header['subject']) === false) {
+            $header['subject'] = array('Subject', 'no subject in original');
+        }
+        if (isset($header['content-type']) === false) {
+            $header['content-type'] = array(
+                'Content-Type',
+                $attach === null ? 'text/plain; charset=iso-2022-jp'
+                                 : "multipart/mixed; \n\tboundary=\"$boundary\"",
+            );
+        }
+
+        $header_line = "";
+        foreach ($header as $key => $value) {
+            if ($key == 'subject') {
+                // should be added by mail()
+                continue;
+            }
+            if ($header_line != "") {
+                $header_line .= "\n";
+            }
+            $header_line .= $value[0] . ": " . $value[1];
+        }
+
+        // ԥɤ CRLF 
+        if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
+            $body = str_replace("\n", "\r\n", $body);
+        }
+        $header_line = str_replace("\n", "\r\n", $header_line);
+
+        // 
+        foreach (to_array($to) as $rcpt) {
             if (is_string($this->option)) {
                 mail($rcpt, $header['subject'][1], $body, $header_line, $this->option);
             } else {
                 mail($rcpt, $header['subject'][1], $body, $header_line);
             }
-
         }
     }
 
