@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Util.php,v 1.25 2006/11/20 09:13:30 ichii386 Exp $
+ *  @version    $Id: Ethna_Util.php 468 2007-07-07 07:52:30Z mumumu-org $
  */
 
 // {{{ to_array
@@ -176,7 +176,7 @@ class Ethna_Util
                             $uniqid);
         if (file_exists($filename)) {
             if (unlink($filename) == false) {
-                return Ethna::raiseWarning(E_APP_WRITE, $filename);
+                return Ethna::raiseWarning("ե񤭹ߥ顼[%s]", E_APP_WRITE, $filename);
             }
         }
 
@@ -317,7 +317,7 @@ class Ethna_Util
                             $field .= $line_end;
 
                             // request one more line
-                            return Ethna::raiseNotice(E_UTIL_CSV_CONTINUE);
+                            return Ethna::raiseNotice('CSVʬ䥨顼(Է³)', E_UTIL_CSV_CONTINUE);
                         }
                     }
                 }
@@ -669,6 +669,27 @@ class Ethna_Util
     }
     // }}}
 
+    // {{{ isRootDir
+    /**
+     *  ѥ̾롼ȥǥ쥯ȥ꤫ɤ֤
+     *
+     *  @access public
+     *  @param  string  $path
+     *  @static
+     */
+    function isRootDir($path)
+    {
+        if ($path === DIRECTORY_SEPARATOR) {
+            // avoid stat().
+            return true;
+        }
+        if (is_dir($path) === false) {
+            return false;
+        }
+        return $path === basename($path) . DIRECTORY_SEPARATOR;
+    }
+    // }}}
+
     // {{{ mkdir
     /**
      *  mkdir -p
@@ -802,7 +823,7 @@ class Ethna_Util
         }
         $lh = fopen($file, 'r');
         if ($lh == null) {
-            return Ethna::raiseError(E_APP_READ, "եɤ߹ߥ顼[%s]", $file);
+            return Ethna::raiseError("եɤ߹ߥ顼[%s]", E_APP_READ, $file);
         }
 
         $lock_mode = $mode == 'r' ? LOCK_SH : LOCK_EX;
@@ -816,9 +837,9 @@ class Ethna_Util
         }
         if ($timeout > 0 && $i == $timeout) {
             // timed out
-            return Ethna::raiseError(E_APP_LOCK, "եå顼[%s]", $file);
+            return Ethna::raiseError("եå顼[%s]", E_APP_LOCK, $file);
         }
- 
+
         return $lh;
     }
     // }}}
