@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Handle_AddView.php,v 1.6 2006/11/17 02:32:31 ichii386 Exp $
+ *  @version    $Id: Ethna_Plugin_Handle_AddView.php 444 2007-01-05 06:57:21Z ichii386 $
  */
 
 require_once ETHNA_BASE . '/class/Plugin/Handle/Ethna_Plugin_Handle_AddAction.php';
@@ -36,6 +36,9 @@ class Ethna_Plugin_Handle_AddView extends Ethna_Plugin_Handle_AddAction
 
         // view_name
         $view_name = array_shift($arg_list);
+        if ($view_name == null) {
+            return Ethna::raiseError('view name isn\'t set.', 'usage');
+        }
         $r =& Ethna_Controller::checkViewName($view_name);
         if (Ethna::isError($r)) {
             return $r;
